This is the Select2 widget for `yafowil <http://pypi.python.org/pypi/yafowil>`_,
based on `Select2 <http://ivaynberg.github.com/select2/>`_

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#select2>`_

- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.select2/index.html>`_

- `Select2 <http://ivaynberg.github.com/select2/>`_

Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/conestack/yafowil.widget.select2>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Johannes Raggam

- Robert Niederreiter

- Georg Bernhard
